pub enum PolicyClientSubcommand {
Register(RegisterCommand),
Deactivate(DeactivateCommand),
Activate(ActivateCommand),
TransferOwnership(TransferOwnershipCommand),
Status(StatusCommand),
List(ListCommand),
SetPolicy(SetPolicyCommand),
SetPolicyParams(SetPolicyParamsCommand),
}Variants
Register(RegisterCommand)
Register a policy client with the PolicyClientRegistry
Deactivate(DeactivateCommand)
Deactivate a registered policy client
Activate(ActivateCommand)
Reactivate a previously deactivated policy client
TransferOwnership(TransferOwnershipCommand)
Transfer registry ownership record of a policy client
Status(StatusCommand)
Query registration status and record for a policy client
List(ListCommand)
List all policy clients owned by an address
SetPolicy(SetPolicyCommand)
Set the policy address on a policy client contract (owner-only)
SetPolicyParams(SetPolicyParamsCommand)
Set policy parameters for a policy client