pub async fn execute_wasm(
wasm_file: PathBuf,
input_json: String,
config: NewtonAvsConfig<NewtonCliConfig>,
) -> Result<String>Expand description
Execute WASM with the given file path and input JSON
pub async fn execute_wasm(
wasm_file: PathBuf,
input_json: String,
config: NewtonAvsConfig<NewtonCliConfig>,
) -> Result<String>Execute WASM with the given file path and input JSON