init

Function init 

pub fn init() -> Result<(), Error>
Initialize environment variables for CLI from .env file in current working directory

This function looks for a .env file in the current working directory (where the command is executed). This works for both development and published binaries.

If APP_BASE_DIR environment variable is set, it will look for the .env file in that directory instead.

The .env file is optional - if it doesn’t exist, the function silently returns Ok(()).

Returns

A Result containing the environment variables, or an error if the initialization fails. Errors are typically ignored since .env files are optional.